# Changelog

All notable changes to this project will be documented in this file.

## [0.1.5] - 2026-03-29

### Features

- *(pptx)* Add PPTX generation from IR ([0780c27](https://github.com/ThomAub/officemd/commit/0780c2706da27a2de95eda8390ac535134a41f70))

### Miscellaneous

- Release v0.1.4 ([1289d01](https://github.com/ThomAub/officemd/commit/1289d011ddbda12b4891b784eaf2b92bf843f979))

